@@ -15,7 +15,10 @@
 #' @param border color of the border
 #' @param ncol number of columns for the output tabs
 #' @param ylim range of the values to be plotted.
-#' 
+#' @param legend.label Label for the color legend.
+#' @param per1000 logical indicator to plot mortality rates as rates per 1,000 live births. Note that the added comparison data should always be in the probability scale.
+#' @param clean remove all coordinates for a cleaner layout, default to TRUE.
+#' importFrom sp proj4string
 #' @examples
 #' \dontrun{
 #' data(DemoMap)
@@ -41,7 +44,7 @@
 #' }
 #' 
 #' @export
-mapPlot <- function(data, variables, values = NULL, labels = NULL, geo, by.data, by.geo, is.long = FALSE, size = 0.5, removetab = FALSE, border = "gray20", ncol = NULL, ylim = NULL){
+mapPlot <- function(data, variables, values = NULL, labels = NULL, geo, by.data, by.geo, is.long = FALSE, size = 0.5, removetab = FALSE, border = "gray20", ncol = NULL, ylim = NULL, legend.label = NULL,  per1000 = FALSE, clean = TRUE){
     value <- group <- lat <- long <- NULL
     if (is.null(labels) & !is.long) {
         labels <- variables
@@ -52,6 +55,7 @@ mapPlot <- function(data, variables, values = NULL, labels = NULL, geo, by.data,
     if (is.null(values) & is.long) {
         stop("values need to be specified for long format input.")
     }
+    has.coord <- !is.na(sp::proj4string(geo))
     geo <- ggplot2::fortify(geo, region = by.geo)
     if (!is.long) {
         data <- data[, c(variables, by.data)]
@@ -65,6 +69,9 @@ mapPlot <- function(data, variables, values = NULL, labels = NULL, geo, by.data,
         data$variable <- as.character(data$variable)
         data$variable <- factor(data$variable, levels = labels)
     }
+    if(per1000){
+        data$value <- data$value * 1000
+    }
     geo2 <- merge(geo, data, by = "id", by.y = by.data)
     g <- ggplot2::ggplot(geo2)
     g <- g + ggplot2::geom_polygon(ggplot2::aes(x = long, y = lat, 
@@ -76,11 +83,19 @@ mapPlot <- function(data, variables, values = NULL, labels = NULL, geo, by.data,
             g <- g + ggplot2::facet_wrap(~variable, ncol = ncol)
         }
     }
+    if(is.null(legend.label)){
+        legend.label <- "Value"
+    }
     if(!is.null(ylim)){
-        g <- g + ggplot2::scale_fill_viridis_c(lim = ylim)
+        g <- g + ggplot2::scale_fill_viridis_c(legend.label, lim = ylim)
     }else{
-        g <- g + ggplot2::scale_fill_viridis_c()
+        g <- g + ggplot2::scale_fill_viridis_c(legend.label)
     } 
+    if(has.coord) g <- g + ggplot2::coord_map()
+
+    if(clean){
+        g <- g + ggplot2::theme_bw() + ggplot2::theme(legend.title=ggplot2::element_text(size=ggplot2::rel(0.7)), axis.title.x=ggplot2::element_blank(), axis.text.x=ggplot2::element_blank(), axis.ticks.x=ggplot2::element_blank(), axis.title.y=ggplot2::element_blank(), axis.text.y=ggplot2::element_blank(), axis.ticks.y=ggplot2::element_blank(), panel.grid.major = ggplot2::element_blank(), panel.grid.minor = ggplot2::element_blank())
+    }
 
     return(g)
 }
